#include "multifolderview.h"
#include <QPainter>
#include <QFontMetrics>
#include <QSizeF>
#include <KLocale>
#include <QGraphicsLinearLayout>
#include "strippedFolderView.h"
#include <plasma/svg.h>
#include <plasma/theme.h>
#include <qdir.h>
#include "label.h"

MultiFolderView::MultiFolderView(QObject *parent, const QVariantList &args)
    : Plasma::Containment(parent, args)
{
    setBackgroundHints(Applet::TranslucentBackground);
	setAspectRatioMode(Plasma::IgnoreAspectRatio);
    setHasConfigurationInterface(false);
    resize(200, 200);
	
	QString configFile = QString("%1%2").arg(QDir::homePath()).arg("/.caixamagica/folderViewConfig.ini");
	KConfig config(configFile);
	m_general = new KConfigGroup(&config, "General");
	m_url 		= m_general->readPathEntry( "Folder", QString("%1%2").arg(QDir::homePath()).arg("/.caixamagica/") );
	m_cols 		= m_general->readEntry( "Columns", 1 );																
	m_iconsize 	= m_general->readEntry("IconSize", 64);
	
	m_general->writePathEntry( "Folder", m_url );
	m_general->writeEntry( "Columns", m_cols );
	m_general->writeEntry("IconSize", m_iconsize);
	
	m_general->config()->sync();	
}


MultiFolderView::~MultiFolderView()
{

}

void MultiFolderView::init()
{
    QDir d(m_url);
    d.setFilter(QDir::AllDirs | QDir::NoDotAndDotDot);
    
    QStringList folders = d.entryList();
    if( m_cols == 0){
      m_cols = 1;
    }
    
    QGraphicsLinearLayout *l = new QGraphicsLinearLayout();
    l->setOrientation(Qt::Vertical);
    l->setSpacing(0);
    
    if (m_cols != 1){
      l->setOrientation(Qt::Horizontal);
      for(int i = 0; i < m_cols; ++i){
        QGraphicsWidget *w = new QGraphicsWidget(this);
        QGraphicsLinearLayout *vLayout = new QGraphicsLinearLayout();
        vLayout->setOrientation(Qt::Vertical);
        vLayout->setSpacing(0);
        w->setLayout(vLayout);
        m_verticalWidgets.append(w);
      }
    }

    for(int i = 0; i < folders.size(); ++i){
        QString folder = QString("%1/%2").arg(m_url).arg(folders[i]);
        StrippedFolderView *v = new StrippedFolderView(this, folder, QSize(m_iconsize,m_iconsize));
        Label *label = new Label(this, folders[i]);
        label->setDrawShadow(true);
        label->setFont(v->font());

        if( m_cols == 1 ){
            l->addItem(label);
            l->addItem(v);
            continue;
        }
        
        QGraphicsLinearLayout *layout = (QGraphicsLinearLayout*) m_verticalWidgets[ i % m_cols ]->layout();
        layout->addItem(label);
        layout->addItem(v);
    }

    if( m_cols != 1){
      foreach(QGraphicsWidget *w, m_verticalWidgets){
        l->addItem(w);
      }
    }
    setLayout(l);
}

#include "multifolderview.moc"

